<template>
  <a-card :bordered="false" :class="'cust-erp-sub-tab'">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class="table-operator" v-if="mainId">
      <a-button @click="handleAdd" type="primary" icon="plus" :disabled="!this.mainId">新增</a-button>
      <a-button type="primary" icon="download" @click="handleExportXls('仓库服务对象')" v-if="false">导出</a-button>
      <a-upload
        name="file"
        :showUploadList="false"
        :multiple="false"
        :headers="tokenHeader"
        :action="importExcelUrl"
        @change="handleImportExcel">
          <a-button type="primary" icon="import" v-if="false">导入</a-button>
      </a-upload>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item key="1" @click="batchDel"><a-icon type="delete"/>删除</a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作 <a-icon type="down" /></a-button>
      </a-dropdown>
    </div>
    <!-- table区域-begin -->
    <div>
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :scroll="{x:true}"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        @change="handleTableChange">

        <template slot="htmlSlot" slot-scope="text">
          <div v-html="text"></div>
        </template>
        <template slot="imgSlot" slot-scope="text,record">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无图片</span>
          <img v-else :src="getImgView(text)" :preview="record.id" height="25px" alt="" style="max-width:80px;font-size: 12px;font-style: italic;"/>
        </template>
        <template slot="fileSlot" slot-scope="text">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无文件</span>
          <a-button
            v-else
            :ghost="true"
            type="primary"
            icon="download"
            size="small"
            @click="downloadFile(text)">
            下载
          </a-button>
        </template>

        <span slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)">编辑</a>
          <a-divider type="vertical" />
          <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
            <a>删除</a>
          </a-popconfirm>
        </span>

      </a-table>
    </div>
    <production-line-warehouse-client-modal
    ref="modalForm" 
    @ok="modalFormOk" 
    :mainId="mainId"
    :enterpriseId="enterpriseId"
    :originTargetKeys="originTargetKeys"
    ></production-line-warehouse-client-modal>
  </a-card>
</template>
<style>
.notShow{
  display: none}
</style>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { getAction } from '../../api/manage'
import ProductionLineWarehouseClientModal from './modules/ProductionLineWarehouseClientModal.vue'
  export default {
    name: "WarehouseClientList",
    mixins:[JeecgListMixin],
    components: {ProductionLineWarehouseClientModal},
    props:{
      mainId:{
        type:String,
        default:'',
        required:false
      },
     workshopId:{
        type:String,
        default:'',
        required:false
      }
    },
    watch:{
      mainId:{
        immediate: true,
        handler(val) {
          if(!this.mainId){
            this.clearList()
          }else{
            this.queryParam['warehouseId'] = val;
            this.queryParam['delFlag'] = '0';
            this.isButtonShow=true;  
            this.loadData(1);
            this.selectedRowKeys=[];
          }
        }
      },
      workshopId:{
        immediate: true,
        handler(val) {
           getAction(this.url.queryFactoryById,{id:val}).then(res=>{
               if(res.success){
                  this.enterpriseId = res.result.enterpriseId
               }
               else{
                 
               }
           })
        }
      }
    },
    data () {
      return {
        description: '仓库管理页面',
        disableMixinCreated:true,
        enterpriseId:'',
        // 表头
        columns: [
          {
            title: '#',
            dataIndex: '',
            key:'rowIndex',
            align:"center",
            customRender:function (t,r,index) {
              return parseInt(index)+1;
            },
            width:60
          },
          {
            title:'编码',
            align:"center",
            dataIndex: 'code',
          },
          {
            title:'名称',
            align:"center",
            dataIndex: 'name',
          },
          {
            title:'创建人',
            align:"center",
            dataIndex: 'createBy',
            width:200
          },
          {
            title:'创建日期',
            align:"center",
            dataIndex: 'createTime',
            width:200
          },
          {
            title:'更新人',
            align:"center",
            dataIndex: 'updateBy',
            width:200
          },
          {
            title:'更新日期',
            align:"center",
            dataIndex: 'updateTime',
            width:200,
          },
          {
            title: '操作',
            dataIndex: 'action',
            align:"center",
            fixed:"right",
            width:200,
            scopedSlots: { customRender: 'action' },
          }
        ],
        url: {
          list: "/base/productionLineWarehouse/listProductionLineWarehouseClientByMainId",
          delete: "/base/productionLineWarehouse/deleteProductionLineWarehouseClient",
          queryFactoryById:"/base/factoryModel/queryById",
          deleteBatch: "/base/productionLineWarehouse/deleteBatchProductionLineWarehouseClient",
          exportXlsUrl: "/base/productionLineWarehouse/exportProductionLineWarehouseClient",
          importUrl: "/base/productionLineWarehouse/importProductionLineWarehouseClient",
        },
        dictOptions:{
        },
        originTargetKeys:[]
      }
    },
    created() {
    },
    computed: {
      importExcelUrl(){
        return `${window._CONFIG['domianURL']}/${this.url.importUrl}/${this.mainId}`;
      }
    },
    methods: {
      clearList(){
        this.dataSource=[]
        this.selectedRowKeys=[]
        this.ipagination.current = 1
      },
      loadData(arg) {
      if(!this.url.list){
        this.$message.error("请设置url.list属性!")
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1;
      }
      var params = this.getQueryParams();//查询条件
      this.loading = true;
      this.originTargetKeys=[];
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          //update-begin---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
          this.dataSource = res.result.records||res.result;
          for(var i=0;i<res.result.records.length;i++){
            var clientId=res.result.records[i]['clientId']
            this.originTargetKeys.push(clientId)
          }
          if(res.result.total)
          {
            this.ipagination.total = res.result.total;
          }else{
            this.ipagination.total = 0;
          }
          //update-end---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
        }else{
          this.$message.warning(res.message)
        }
      }).finally(() => {
        this.loading = false
      })
    },

    }
  }
</script>
<style scoped>
  @import '~@assets/less/common.less'
</style>
